@@ -23,6 +23,7 @@
 #include <core/mountentry.h>
 
 #include <fs/filesystem.h>
+#include <fs/luks.h>
 
 #include <KLocalizedString>
 #include <KIOCore/KMountPoint>
@@ -43,7 +44,7 @@ static QString findBlkIdDevice(const QString& token, const QString& value)
     blkid_cache cache;
     QString rval;
 
-    if (blkid_get_cache(&cache, NULL) == 0) {
+    if (blkid_get_cache(&cache, nullptr) == 0) {
         if (char* c = blkid_evaluate_tag(token.toLocal8Bit().constData(), value.toLocal8Bit().constData(), &cache)) {
             rval = QString::fromLocal8Bit(c);
             free(c);
@@ -63,13 +64,18 @@ EditMountPointDialogWidget::EditMountPointDialogWidget(QWidget* parent, const Pa
 
     setupUi(this);
 
-    labelName().setText(partition().deviceNode());
+    m_deviceNode = partition().deviceNode();
+    if (partition().roles().has(PartitionRole::Luks) && partition().fileSystem().type() != FileSystem::Luks) {
+        const FS::luks* luksFs = dynamic_cast<const FS::luks*>(&partition().fileSystem());
+        m_deviceNode = luksFs->mapperName(m_deviceNode);
+    }
+    labelName().setText(m_deviceNode);
     labelType().setText(partition().fileSystem().name());
 
-    if (mountPoints().find(partition().deviceNode()) == mountPoints().end())
-        mountPoints()[partition().deviceNode()] = new MountEntry(partition().deviceNode(), QString(), partition().fileSystem().name(), QStringList(), 0, 0, MountEntry::deviceNode);
+    if (mountPoints().find(m_deviceNode) == mountPoints().end())
+        mountPoints()[m_deviceNode] = new MountEntry(m_deviceNode, QString(), partition().fileSystem().name(), QStringList(), 0, 0, MountEntry::deviceNode);
 
-    MountEntry* entry = mountPoints()[partition().deviceNode()];
+    MountEntry* entry = mountPoints()[m_deviceNode];
 
     Q_ASSERT(entry);
 
@@ -167,16 +173,16 @@ bool EditMountPointDialogWidget::readMountpoints(const QString& filename)
 {
     FILE* fp = setmntent(filename.toLocal8Bit().constData(), "r");
 
-    if (fp == NULL) {
+    if (fp == nullptr) {
         KMessageBox::sorry(this,
                            xi18nc("@info", "Could not open mount point file <filename>%1</filename>.", filename),
                            i18nc("@title:window", "Error while reading mount points"));
         return false;
     }
 
-    struct mntent* mnt = NULL;
+    struct mntent* mnt = nullptr;
 
-    while ((mnt = getmntent(fp)) != NULL) {
+    while ((mnt = getmntent(fp)) != nullptr) {
         QString device = QString::fromUtf8(mnt->mnt_fsname);
         MountEntry::IdentifyType type = MountEntry::deviceNode;
 
@@ -204,7 +210,7 @@ static void writeEntry(QFile& output, const MountEntry* entry)
 {
     Q_ASSERT(entry);
 
-    if (entry == NULL)
+    if (entry == nullptr)
         return;
 
     if (entry->path.isEmpty())
@@ -222,7 +228,7 @@ static void writeEntry(QFile& output, const MountEntry* entry)
 
 bool EditMountPointDialogWidget::acceptChanges()
 {
-    MountEntry* entry = NULL;
+    MountEntry* entry = nullptr;
 
     if (mountPoints().find(labelName().text()) == mountPoints().end()) {
         qWarning() << "could not find device " << labelName().text() << " in mount points.";
@@ -241,7 +247,7 @@ bool EditMountPointDialogWidget::acceptChanges()
     else if (radioLabel().isChecked() && !partition().fileSystem().label().isEmpty())
         entry->name = QStringLiteral("LABEL=") + partition().fileSystem().label();
     else
-        entry->name = partition().deviceNode();
+        entry->name = m_deviceNode;
 
     return true;
 }
