@@ -72,7 +72,7 @@ void FileSystemSupportDialog::setupDialog()
     dialogWidget().tree().clear();
 
     foreach(const FileSystem * fs, FileSystemFactory::map()) {
-        if (fs->type() == FileSystem::Unknown || fs->type() == FileSystem::Extended)
+        if (fs->type() == FileSystem::Unknown || fs->type() == FileSystem::Extended || fs->type() == FileSystem::Luks)
             continue;
 
         QTreeWidgetItem* item = new QTreeWidgetItem();
@@ -107,8 +107,8 @@ void FileSystemSupportDialog::setupDialog()
 
 void FileSystemSupportDialog::setupConnections()
 {
-    connect(dialogButtonBox->button(QDialogButtonBox::Ok), SIGNAL(clicked()), SLOT(close()));
-    connect(&dialogWidget().buttonRescan(), SIGNAL(clicked()), SLOT(onButtonRescanClicked()));
+    connect(dialogButtonBox->button(QDialogButtonBox::Ok), &QPushButton::clicked, this, &FileSystemSupportDialog::close);
+    connect(&dialogWidget().buttonRescan(), &QPushButton::clicked, this, &FileSystemSupportDialog::onButtonRescanClicked);
 }
 
 void FileSystemSupportDialog::onButtonRescanClicked()
