@@ -44,7 +44,7 @@ public:
 ListDevices::ListDevices(QWidget* parent) :
     QWidget(parent),
     Ui::ListDevicesBase(),
-    m_ActionCollection(NULL)
+    m_ActionCollection(nullptr)
 {
     setupUi(this);
 }
@@ -62,7 +62,7 @@ void ListDevices::on_m_ListDevices_itemSelectionChanged()
     if (listDevices().selectedItems().size() == 1) {
         ListDeviceWidgetItem* item = dynamic_cast<ListDeviceWidgetItem*>(listDevices().selectedItems()[0]);
 
-        if (item != NULL)
+        if (item != nullptr)
             emit selectionChanged(item->deviceNode);
     }
 }
@@ -76,7 +76,7 @@ void ListDevices::on_m_ListDevices_itemDoubleClicked(QListWidgetItem* list_item)
 {
     ListDeviceWidgetItem* item = dynamic_cast<ListDeviceWidgetItem*>(list_item);
 
-    if (item != NULL)
+    if (item != nullptr)
         emit deviceDoubleClicked(item->deviceNode);
 }
 
