@@ -1,6 +1,7 @@
 /*************************************************************************
  *  Copyright (C) 2008, 2010 by Volker Lanz <vl@fidra.de>                *
  *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
+ *  Copyright (C) 2016 by Teo Mrnjavac <teo@kde.org>                     *
  *                                                                       *
  *  This program is free software; you can redistribute it and/or        *
  *  modify it under the terms of the GNU General Public License as       *
@@ -24,6 +25,7 @@
 #include <core/device.h>
 
 #include <fs/filesystemfactory.h>
+#include <fs/luks.h>
 
 #include <util/capacity.h>
 #include <util/helpers.h>
@@ -32,6 +34,7 @@
 #include <QFontDatabase>
 #include <QtAlgorithms>
 
+#include <KColorScheme>
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KSharedConfig>
@@ -65,14 +68,16 @@ NewDialog::~NewDialog()
 void NewDialog::setupDialog()
 {
     QStringList fsNames;
-    foreach(const FileSystem * fs, FileSystemFactory::map())
-    if (fs->supportCreate() != FileSystem::cmdSupportNone && fs->type() != FileSystem::Extended)
-        fsNames.append(fs->name());
+    foreach (const FileSystem * fs, FileSystemFactory::map())
+        if (fs->supportCreate() != FileSystem::cmdSupportNone &&
+            fs->type() != FileSystem::Extended &&
+            fs->type() != FileSystem::Luks)
+            fsNames.append(fs->name());
 
     qSort(fsNames.begin(), fsNames.end(), caseInsensitiveLessThan);
 
-    foreach(const QString & fsName, fsNames)
-    dialogWidget().comboFileSystem().addItem(createFileSystemColor(FileSystem::typeForName(fsName), 8), fsName);
+    foreach (const QString & fsName, fsNames)
+        dialogWidget().comboFileSystem().addItem(createFileSystemColor(FileSystem::typeForName(fsName), 8), fsName);
 
     QString selected = FileSystem::nameForType(GuiHelpers::defaultFileSystem());
     const int idx = dialogWidget().comboFileSystem().findText(selected);
@@ -89,6 +94,19 @@ void NewDialog::setupDialog()
 
     SizeDialogBase::setupDialog();
 
+    dialogWidget().checkBoxEncrypt().hide();
+    dialogWidget().editPassphrase().hide();
+
+    dialogWidget().editPassphrase().setMinimumPasswordLength(1);
+    dialogWidget().editPassphrase().setMaximumPasswordLength(512); // cryptsetup does not support longer passwords
+
+    // set a background warning color (taken from the current color scheme)
+    KColorScheme colorScheme(QPalette::Active, KColorScheme::View);
+    dialogWidget().editPassphrase().setBackgroundWarningColor(colorScheme.background(KColorScheme::NegativeBackground).color());
+
+    // listen to password status updates
+    connect(&dialogWidget().editPassphrase(), &KNewPasswordWidget::passwordStatusChanged, this, &NewDialog::slotPasswordStatusChanged);
+
     // don't move these above the call to parent's setupDialog, because only after that has
     // run there is a valid partition set in the part resizer widget and they will need that.
     onRoleChanged(false);
@@ -97,11 +115,12 @@ void NewDialog::setupDialog()
 
 void NewDialog::setupConnections()
 {
-    connect(&dialogWidget().radioPrimary(), SIGNAL(toggled(bool)), SLOT(onRoleChanged(bool)));
-    connect(&dialogWidget().radioExtended(), SIGNAL(toggled(bool)), SLOT(onRoleChanged(bool)));
-    connect(&dialogWidget().radioLogical(), SIGNAL(toggled(bool)), SLOT(onRoleChanged(bool)));
-    connect(&dialogWidget().comboFileSystem(), SIGNAL(currentIndexChanged(int)), SLOT(onFilesystemChanged(int)));
-    connect(&dialogWidget().label(), SIGNAL(textChanged(const QString&)), SLOT(onLabelChanged(const QString&)));
+    connect(&dialogWidget().radioPrimary(), &QRadioButton::toggled, this, &NewDialog::onRoleChanged);
+    connect(&dialogWidget().radioExtended(), &QRadioButton::toggled, this, &NewDialog::onRoleChanged);
+    connect(&dialogWidget().radioLogical(), &QRadioButton::toggled, this, &NewDialog::onRoleChanged);
+    connect(&dialogWidget().checkBoxEncrypt(), &QCheckBox::toggled, this, &NewDialog::onRoleChanged);
+    connect(&dialogWidget().comboFileSystem(), static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &NewDialog::onFilesystemChanged);
+    connect(&dialogWidget().label(), &QLineEdit::textChanged, this, &NewDialog::onLabelChanged);
 
     SizeDialogBase::setupConnections();
 }
@@ -110,7 +129,21 @@ void NewDialog::accept()
 {
     if (partition().roles().has(PartitionRole::Extended)) {
         partition().deleteFileSystem();
-        partition().setFileSystem(FileSystemFactory::create(FileSystem::Extended, partition().firstSector(), partition().lastSector()));
+        partition().setFileSystem(FileSystemFactory::create(FileSystem::Extended,
+                                                            partition().firstSector(),
+                                                            partition().lastSector()));
+    }
+    else if (partition().roles().has(PartitionRole::Luks)) {
+        FileSystem::Type innerFsType = partition().fileSystem().type();
+        partition().deleteFileSystem();
+        FS::luks* luksFs = dynamic_cast< FS::luks* >(
+                               FileSystemFactory::create(FileSystem::Luks,
+                                                         partition().firstSector(),
+                                                         partition().lastSector()));
+        luksFs->createInnerFileSystem(innerFsType);
+        luksFs->setPassphrase(dialogWidget().editPassphrase().password());
+        partition().setFileSystem(luksFs);
+        partition().fileSystem().setLabel(dialogWidget().label().text());
     }
 
     QDialog::accept();
@@ -127,6 +160,13 @@ void NewDialog::onRoleChanged(bool)
     else if (dialogWidget().radioLogical().isChecked())
         r = PartitionRole::Logical;
 
+    bool doEncrypt = dialogWidget().checkBoxEncrypt().isVisible() &&
+                       dialogWidget().checkBoxEncrypt().isChecked();
+    if (doEncrypt)
+        r |= PartitionRole::Luks;
+
+    dialogWidget().editPassphrase().setVisible(doEncrypt);
+
     // Make sure an extended partition gets correctly displayed: Set its file system to extended.
     // Also make sure to set a primary's or logical's file system once the user goes back from
     // extended to any of those.
@@ -172,6 +212,21 @@ void NewDialog::onLabelChanged(const QString& newLabel)
     partition().fileSystem().setLabel(newLabel);
 }
 
+void NewDialog::slotPasswordStatusChanged()
+{
+    // You may want to extend this switch with more cases,
+    // in order to warn the user about all the possible password issues.
+    switch (dialogWidget().editPassphrase().passwordStatus()) {
+    case KNewPasswordWidget::WeakPassword:
+    case KNewPasswordWidget::StrongPassword:
+        okButton->setEnabled(true);
+        break;
+    default:
+        okButton->setEnabled(false);
+        break;
+    }
+}
+
 void NewDialog::updateHideAndShow()
 {
     // this is mostly copy'n'pasted from PartPropsDialog::updateHideAndShow()
@@ -185,8 +240,25 @@ void NewDialog::updateHideAndShow()
         f.setAlpha(128);
         palette.setColor(QPalette::Foreground, f);
         dialogWidget().noSetLabel().setPalette(palette);
+        dialogWidget().checkBoxEncrypt().hide();
+        dialogWidget().editPassphrase().hide();
     } else {
         dialogWidget().label().setReadOnly(false);
         dialogWidget().noSetLabel().setVisible(false);
     }
+    if (FS::luks::canEncryptType(FileSystem::typeForName(dialogWidget().comboFileSystem().currentText())) && !partition().roles().has(PartitionRole::Extended) )
+    {
+        dialogWidget().checkBoxEncrypt().show();
+        if (dialogWidget().checkBoxEncrypt().isChecked())
+        {
+            dialogWidget().editPassphrase().show();
+            slotPasswordStatusChanged();
+        }
+    }
+    else
+    {
+        dialogWidget().checkBoxEncrypt().hide();
+        dialogWidget().editPassphrase().hide();
+    }
+
 }
