@@ -35,33 +35,31 @@ class Device;
 */
 class NewDialog : public SizeDialogBase
 {
-    Q_OBJECT
-
 public:
     NewDialog(QWidget* parent, Device& device, Partition& unallocatedPartition, PartitionRole::Roles r);
     ~NewDialog();
 
-protected Q_SLOTS:
-    void accept();
+protected:
+    void accept() override;
     void onRoleChanged(bool);
     void onFilesystemChanged(int);
     void onLabelChanged(const QString& newLabel);
 
-protected:
-    void setupConnections();
-    void setupDialog();
+    void setupConnections() override;
+    void setupDialog() override;
+    void slotPasswordStatusChanged();
     void updateHideAndShow();
     void updateFileSystem(FileSystem::Type t);
     PartitionRole::Roles partitionRoles() const {
         return m_PartitionRoles;
     }
-    virtual bool canGrow() const {
+    bool canGrow() const override {
         return true;
     }
-    virtual bool canShrink() const {
+    bool canShrink() const override {
         return true;
     }
-    virtual bool canMove() const {
+    bool canMove() const override {
         return true;
     }
 
