@@ -1,5 +1,6 @@
 /*************************************************************************
  *  Copyright (C) 2008-2010 by Volker Lanz <vl@fidra.de>                 *
+ *  Copyright (C) 2015 by Teo Mrnjavac <teo@kde.org>                     *
  *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
  *                                                                       *
  *  This program is free software; you can redistribute it and/or        *
@@ -30,6 +31,7 @@
 #include <core/partitiontable.h>
 
 #include <fs/filesystemfactory.h>
+#include <fs/luks.h>
 
 #include <gui/partwidget.h>
 
@@ -48,6 +50,7 @@
 #include <util/capacity.h>
 #include <util/report.h>
 #include <util/helpers.h>
+
 #include "util/guihelpers.h"
 
 #include <QCursor>
@@ -62,6 +65,8 @@
 
 #include <config.h>
 
+#include <typeinfo>
+
 class PartitionTreeWidgetItem : public QTreeWidgetItem
 {
     Q_DISABLE_COPY(PartitionTreeWidgetItem)
@@ -82,9 +87,9 @@ private:
 PartitionManagerWidget::PartitionManagerWidget(QWidget* parent) :
     QWidget(parent),
     Ui::PartitionManagerWidgetBase(),
-    m_OperationStack(NULL),
-    m_SelectedDevice(NULL),
-    m_ClipboardPartition(NULL)
+    m_OperationStack(nullptr),
+    m_SelectedDevice(nullptr),
+    m_ClipboardPartition(nullptr)
 {
     setupUi(this);
 
@@ -148,22 +153,22 @@ void PartitionManagerWidget::saveConfig() const
 
 void PartitionManagerWidget::setupConnections()
 {
-    connect(treePartitions().header(), SIGNAL(customContextMenuRequested(const QPoint&)), SLOT(onHeaderContextMenu(const QPoint&)));
+    connect(treePartitions().header(), &QHeaderView::customContextMenuRequested, this, &PartitionManagerWidget::onHeaderContextMenu);
 }
 
 void PartitionManagerWidget::clear()
 {
-    setSelectedDevice(NULL);
-    setClipboardPartition(NULL);
+    setSelectedDevice(nullptr);
+    setClipboardPartition(nullptr);
     treePartitions().clear();
     partTableWidget().clear();
 }
 
 void PartitionManagerWidget::setSelectedPartition(const Partition* p)
 {
-    if (p == NULL) {
-        treePartitions().setCurrentItem(NULL);
-        emit selectedPartitionChanged(NULL);
+    if (p == nullptr) {
+        treePartitions().setCurrentItem(nullptr);
+        emit selectedPartitionChanged(nullptr);
         updatePartitions();
     } else
         partTableWidget().setActivePartition(p);
@@ -171,8 +176,8 @@ void PartitionManagerWidget::setSelectedPartition(const Partition* p)
 
 Partition* PartitionManagerWidget::selectedPartition()
 {
-    if (selectedDevice() == NULL || selectedDevice()->partitionTable() == NULL || partTableWidget().activeWidget() == NULL)
-        return NULL;
+    if (selectedDevice() == nullptr || selectedDevice()->partitionTable() == nullptr || partTableWidget().activeWidget() == nullptr)
+        return nullptr;
 
     // The active partition we get from the part table widget is const; we need non-const.
     // So take the first sector and find the partition in the selected device's
@@ -191,13 +196,13 @@ void PartitionManagerWidget::setSelectedDevice(const QString& device_node)
         return;
     }
 
-    setSelectedDevice(NULL);
+    setSelectedDevice(nullptr);
 }
 
 void PartitionManagerWidget::setSelectedDevice(Device* d)
 {
     m_SelectedDevice = d;
-    setSelectedPartition(NULL);
+    setSelectedPartition(nullptr);
 }
 
 static QTreeWidgetItem* createTreeWidgetItem(const Partition& p)
@@ -207,7 +212,10 @@ static QTreeWidgetItem* createTreeWidgetItem(const Partition& p)
     quint32 i = 0;
     item->setText(i++, p.deviceNode());
 
-    item->setText(i, p.fileSystem().name());
+    if (p.roles().has(PartitionRole::Luks) && p.fileSystem().name() != p.fileSystem().nameForType(FileSystem::Luks))
+        item->setText(i, p.fileSystem().name() + QStringLiteral(" [") + p.fileSystem().nameForType(FileSystem::Luks) + QStringLiteral("]")); // FIXME after string freeze
+    else
+        item->setText(i, p.fileSystem().name());
     item->setIcon(i, createFileSystemColor(p.fileSystem().type(), 14));
     i++;
 
@@ -235,7 +243,7 @@ static QTreeWidgetItem* createTreeWidgetItem(const Partition& p)
 
 void PartitionManagerWidget::updatePartitions()
 {
-    if (selectedDevice() == NULL)
+    if (selectedDevice() == nullptr)
         return;
 
     treePartitions().clear();
@@ -257,7 +265,7 @@ void PartitionManagerWidget::updatePartitions()
 
     treePartitions().addTopLevelItem(deviceItem);
 
-    if (selectedDevice()->partitionTable() != NULL) {
+    if (selectedDevice()->partitionTable() != nullptr) {
         foreach(const Partition * p, selectedDevice()->partitionTable()->children()) {
             QTreeWidgetItem* item = createTreeWidgetItem(*p);
 
@@ -282,18 +290,18 @@ void PartitionManagerWidget::on_m_TreePartitions_currentItemChanged(QTreeWidgetI
 {
     if (current) {
         const PartitionTreeWidgetItem* ptwItem = dynamic_cast<PartitionTreeWidgetItem*>(current);
-        partTableWidget().setActivePartition(ptwItem ? ptwItem->partition() : NULL);
+        partTableWidget().setActivePartition(ptwItem ? ptwItem->partition() : nullptr);
     } else
-        partTableWidget().setActiveWidget(NULL);
+        partTableWidget().setActiveWidget(nullptr);
 }
 
 void PartitionManagerWidget::on_m_TreePartitions_itemDoubleClicked(QTreeWidgetItem* item, int)
 {
     if (item == treePartitions().topLevelItem(0)) {
-        if (selectedDevice() != NULL)
+        if (selectedDevice() != nullptr)
             emit deviceDoubleClicked(selectedDevice());
     } else {
-        if (selectedPartition() != NULL)
+        if (selectedPartition() != nullptr)
             emit partitionDoubleClicked(selectedPartition());
     }
 }
@@ -305,9 +313,9 @@ void PartitionManagerWidget::onHeaderContextMenu(const QPoint& p)
 
 void PartitionManagerWidget::on_m_PartTableWidget_itemSelectionChanged(PartWidget* item)
 {
-    if (item == NULL) {
-        treePartitions().setCurrentItem(NULL);
-        emit selectedPartitionChanged(NULL);
+    if (item == nullptr) {
+        treePartitions().setCurrentItem(nullptr);
+        emit selectedPartitionChanged(nullptr);
         return;
     }
 
@@ -377,19 +385,19 @@ void PartitionManagerWidget::onMountPartition()
 
     Q_ASSERT(p);
 
-    if (p == NULL) {
+    if (p == nullptr) {
         qWarning() << "no partition selected";
         return;
     }
 
-    Report report(NULL);
+    Report report(nullptr);
 
     if (p->canMount()) {
         if (!p->mount(report))
             KMessageBox::detailedSorry(this, xi18nc("@info", "The file system on partition <filename>%1</filename> could not be mounted.", p->deviceNode()), QStringLiteral("<pre>%1</pre>").arg(report.toText()), i18nc("@title:window", "Could Not Mount File System."));
     } else if (p->canUnmount()) {
         if (!p->unmount(report))
-            KMessageBox::detailedSorry(this, xi18nc("@info", "The file system on partition <filename>%1</filename> could not be unmounted.", p->deviceNode()), QStringLiteral("pre>%1</pre>").arg(report.toText()), i18nc("@title:window", "Could Not Unmount File System."));
+            KMessageBox::detailedSorry(this, xi18nc("@info", "The file system on partition <filename>%1</filename> could not be unmounted.", p->deviceNode()), QStringLiteral("<pre>%1</pre>").arg(report.toText()), i18nc("@title:window", "Could Not Unmount File System."));
     }
 
     if (p->roles().has(PartitionRole::Logical)) {
@@ -397,7 +405,7 @@ void PartitionManagerWidget::onMountPartition()
 
         Q_ASSERT(parent);
 
-        if (parent != NULL)
+        if (parent != nullptr)
             parent->checkChildrenMounted();
         else
             qWarning() << "parent is null";
@@ -406,13 +414,59 @@ void PartitionManagerWidget::onMountPartition()
     updatePartitions();
 }
 
+void PartitionManagerWidget::onDecryptPartition()
+{
+    Partition* p = selectedPartition();
+
+    Q_ASSERT(p);
+
+    if (p == nullptr) {
+        qWarning() << "no partition selected";
+        return;
+    }
+
+    if (!p->roles().has(PartitionRole::Luks))
+        return;
+
+    const FileSystem& fsRef = p->fileSystem();
+    FS::luks* luksFs = const_cast<FS::luks*>(dynamic_cast<const FS::luks*>(&fsRef));
+    if (!luksFs)
+        return;
+
+    if (luksFs->canCryptOpen(p->partitionPath())) {
+        if (!luksFs->cryptOpen(this, p->partitionPath()))
+            KMessageBox::detailedSorry(this,
+                                       xi18nc("@info",
+                                              "The encrypted file system on partition "
+                                              "<filename>%1</filename> could not be "
+                                              "unlocked.",
+                                              p->deviceNode()),
+                                       QString(),
+                                       i18nc("@title:window",
+                                             "Could Not Unlock Encrypted File System."));
+    } else if (luksFs->canCryptClose(p->partitionPath())) {
+        if (!luksFs->cryptClose(p->partitionPath()))
+            KMessageBox::detailedSorry(this,
+                                       xi18nc("@info",
+                                              "The encrypted file system on partition "
+                                              "<filename>%1</filename> could not be "
+                                              "locked.",
+                                              p->deviceNode()),
+                                       QString(),
+                                       i18nc("@title:window",
+                                             "Could Not Lock Encrypted File System."));
+    }
+
+    updatePartitions();
+}
+
 void PartitionManagerWidget::onEditMountPoint()
 {
     Partition* p = selectedPartition();
 
     Q_ASSERT(p);
 
-    if (p == NULL)
+    if (p == nullptr)
         return;
 
     QPointer<EditMountPointDialog> dlg = new EditMountPointDialog(this, *p);
@@ -445,14 +499,14 @@ void PartitionManagerWidget::onNewPartition()
     Q_ASSERT(selectedDevice());
     Q_ASSERT(selectedPartition());
 
-    if (selectedDevice() == NULL || selectedPartition() == NULL) {
+    if (selectedDevice() == nullptr || selectedPartition() == nullptr) {
         qWarning() << "selected device: " << selectedDevice() << ", selected partition: " << selectedPartition();
         return;
     }
 
     Q_ASSERT(selectedDevice()->partitionTable());
 
-    if (selectedDevice()->partitionTable() == NULL) {
+    if (selectedDevice()->partitionTable() == nullptr) {
         qWarning() << "partition table on selected device is null";
         return;
     }
@@ -476,7 +530,7 @@ void PartitionManagerWidget::onDeletePartition(bool shred)
     Q_ASSERT(selectedDevice());
     Q_ASSERT(selectedPartition());
 
-    if (selectedDevice() == NULL || selectedPartition() == NULL) {
+    if (selectedDevice() == nullptr || selectedPartition() == nullptr) {
         qWarning() << "selected device: " << selectedDevice() << ", selected partition: " << selectedPartition();
         return;
     }
@@ -484,7 +538,7 @@ void PartitionManagerWidget::onDeletePartition(bool shred)
     if (selectedPartition()->roles().has(PartitionRole::Logical)) {
         Q_ASSERT(selectedPartition()->parent());
 
-        if (selectedPartition()->parent() == NULL) {
+        if (selectedPartition()->parent() == nullptr) {
             qWarning() << "parent of selected partition is null.";
             return;
         }
@@ -511,7 +565,7 @@ void PartitionManagerWidget::onDeletePartition(bool shred)
                                                KStandardGuiItem::cancel(), QStringLiteral("reallyDeleteClipboardPartition")) == KMessageBox::Cancel)
             return;
 
-        setClipboardPartition(NULL);
+        setClipboardPartition(nullptr);
     }
 
     if (shred && Config::shredSource() == Config::EnumShredSource::random)
@@ -532,14 +586,14 @@ void PartitionManagerWidget::onResizePartition()
     Q_ASSERT(selectedDevice());
     Q_ASSERT(selectedPartition());
 
-    if (selectedDevice() == NULL || selectedPartition() == NULL) {
+    if (selectedDevice() == nullptr || selectedPartition() == nullptr) {
         qWarning() << "selected device: " << selectedDevice() << ", selected partition: " << selectedPartition();
         return;
     }
 
     Q_ASSERT(selectedDevice()->partitionTable());
 
-    if (selectedDevice()->partitionTable() == NULL) {
+    if (selectedDevice()->partitionTable() == nullptr) {
         qWarning() << "partition table on selected device is null";
         return;
     }
@@ -577,7 +631,7 @@ void PartitionManagerWidget::onCopyPartition()
 {
     Q_ASSERT(selectedPartition());
 
-    if (selectedPartition() == NULL) {
+    if (selectedPartition() == nullptr) {
         qWarning() << "selected partition: " << selectedPartition();
         return;
     }
@@ -591,12 +645,12 @@ void PartitionManagerWidget::onPastePartition()
     Q_ASSERT(selectedDevice());
     Q_ASSERT(selectedPartition());
 
-    if (selectedDevice() == NULL || selectedPartition() == NULL) {
+    if (selectedDevice() == nullptr || selectedPartition() == nullptr) {
         qWarning() << "selected device: " << selectedDevice() << ", selected partition: " << selectedPartition();
         return;
     }
 
-    if (clipboardPartition() == NULL) {
+    if (clipboardPartition() == nullptr) {
         qWarning() << "no partition in the clipboard.";
         return;
     }
@@ -608,7 +662,7 @@ void PartitionManagerWidget::onPastePartition()
 
     Q_ASSERT(dSource);
 
-    if (dSource == NULL) {
+    if (dSource == nullptr) {
         qWarning() << "source partition is null.";
         return;
     }
@@ -626,7 +680,7 @@ bool PartitionManagerWidget::showInsertDialog(Partition& insertedPartition, qint
     Q_ASSERT(selectedDevice());
     Q_ASSERT(selectedPartition());
 
-    if (selectedDevice() == NULL || selectedPartition() == NULL) {
+    if (selectedDevice() == nullptr || selectedPartition() == nullptr) {
         qWarning() << "selected device: " << selectedDevice() << ", selected partition: " << selectedPartition();
         return false;
     }
@@ -682,7 +736,7 @@ void PartitionManagerWidget::onCheckPartition()
     Q_ASSERT(selectedDevice());
     Q_ASSERT(selectedPartition());
 
-    if (selectedDevice() == NULL || selectedPartition() == NULL) {
+    if (selectedDevice() == nullptr || selectedPartition() == nullptr) {
         qWarning() << "selected device: " << selectedDevice() << ", selected partition: " << selectedPartition();
         return;
     }
@@ -695,12 +749,12 @@ void PartitionManagerWidget::onBackupPartition()
     Q_ASSERT(selectedDevice());
     Q_ASSERT(selectedPartition());
 
-    if (selectedDevice() == NULL || selectedPartition() == NULL) {
+    if (selectedDevice() == nullptr || selectedPartition() == nullptr) {
         qWarning() << "selected device: " << selectedDevice() << ", selected partition: " << selectedPartition();
         return;
     }
 
-    QString fileName = QFileDialog::getSaveFileName(this, QStringLiteral("kfiledialog://backupPartition"));
+    QString fileName = QFileDialog::getSaveFileName(this);
 //  QString fileName = "/tmp/backuptest.img";
 
     if (fileName.isEmpty())
@@ -715,7 +769,7 @@ void PartitionManagerWidget::onRestorePartition()
     Q_ASSERT(selectedDevice());
     Q_ASSERT(selectedPartition());
 
-    if (selectedDevice() == NULL || selectedPartition() == NULL) {
+    if (selectedDevice() == nullptr || selectedPartition() == nullptr) {
         qWarning() << "selected device: " << selectedDevice() << ", selected partition: " << selectedPartition();
         return;
     }
@@ -723,7 +777,7 @@ void PartitionManagerWidget::onRestorePartition()
     if (checkTooManyPartitions(this, *selectedDevice(), *selectedPartition()))
         return;
 
-    QString fileName = QFileDialog::getOpenFileName(this, QStringLiteral("kfiledialog://restorePartition"));
+    QString fileName = QFileDialog::getOpenFileName(this);
 //  QString fileName = "/tmp/backuptest.img";
 
     if (!fileName.isEmpty() && QFile::exists(fileName)) {
