@@ -1,5 +1,6 @@
 /*************************************************************************
  *  Copyright (C) 2008-2010 by Volker Lanz <vl@fidra.de>                 *
+ *  Copyright (C) 2015 by Teo Mrnjavac <teo@kde.org>                     *
  *                                                                       *
  *  This program is free software; you can redistribute it and/or        *
  *  modify it under the terms of the GNU General Public License as       *
@@ -44,7 +45,7 @@ class PartitionManagerWidget : public QWidget, Ui::PartitionManagerWidgetBase
     Q_DISABLE_COPY(PartitionManagerWidget)
 
 public:
-    PartitionManagerWidget(QWidget* parent = NULL);
+    PartitionManagerWidget(QWidget* parent = nullptr);
     virtual ~PartitionManagerWidget();
 
 Q_SIGNALS:
@@ -53,7 +54,7 @@ Q_SIGNALS:
     void deviceDoubleClicked(const Device*);
     void partitionDoubleClicked(const Partition* p);
 
-public Q_SLOTS:
+public:
     void setSelectedDevice(Device* d);
     void setSelectedDevice(const QString& device_node);
 
@@ -67,6 +68,7 @@ public Q_SLOTS:
 
     void onEditMountPoint();
     void onMountPartition();
+    void onDecryptPartition();
 
     void onCheckPartition();
 
@@ -75,7 +77,6 @@ public Q_SLOTS:
 
     void onPropertiesPartition();
 
-public:
     void init(OperationStack* ostack);
 
     void clear();
@@ -133,6 +134,8 @@ protected:
         return *m_TreePartitions;
     }
 
+    void onHeaderContextMenu(const QPoint& p);
+
 protected Q_SLOTS:
     void on_m_TreePartitions_currentItemChanged(QTreeWidgetItem* current, QTreeWidgetItem* previous);
     void on_m_TreePartitions_customContextMenuRequested(const QPoint& pos);
@@ -142,8 +145,6 @@ protected Q_SLOTS:
     void on_m_PartTableWidget_customContextMenuRequested(const QPoint& pos);
     void on_m_PartTableWidget_itemDoubleClicked();
 
-    void onHeaderContextMenu(const QPoint& p);
-
 private:
     OperationStack* m_OperationStack;
     Device* m_SelectedDevice;
