@@ -107,8 +107,8 @@ void PartPropsDialog::setupDialog()
     okButton->setEnabled(false);
     cancelButton->setFocus();
     cancelButton->setDefault(true);
-    connect(dialogButtonBox, SIGNAL(accepted()), this, SLOT(accept()));
-    connect(dialogButtonBox, SIGNAL(rejected()), this, SLOT(reject()));
+    connect(dialogButtonBox, &QDialogButtonBox::accepted, this, &PartPropsDialog::accept);
+    connect(dialogButtonBox, &QDialogButtonBox::rejected, this, &PartPropsDialog::reject);
 
     dialogWidget().partWidget().init(&partition());
 
@@ -189,7 +189,7 @@ void PartPropsDialog::updateHideAndShow()
     // create a temporary fs for some checks
     const FileSystem* fs = FileSystemFactory::create(newFileSystemType(), -1, -1, -1, QString());
 
-    if (fs == NULL || fs->supportSetLabel() == FileSystem::cmdSupportNone) {
+    if (fs == nullptr || fs->supportSetLabel() == FileSystem::cmdSupportNone) {
         dialogWidget().label().setReadOnly(true);
         dialogWidget().noSetLabel().setVisible(true);
         dialogWidget().noSetLabel().setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
@@ -207,7 +207,7 @@ void PartPropsDialog::updateHideAndShow()
     // when do we show the uuid?
     const bool showUuid =
         partition().state() != Partition::StateNew &&                           // not for new partitions
-        !(fs == NULL || fs->supportGetUUID() == FileSystem::cmdSupportNone);       // not if the FS doesn't support it
+        !(fs == nullptr || fs->supportGetUUID() == FileSystem::cmdSupportNone);       // not if the FS doesn't support it
 
     dialogWidget().showUuid(showUuid);
 
@@ -226,8 +226,9 @@ void PartPropsDialog::updateHideAndShow()
     // when do we show the file system combo box?
     const bool showFileSystem =
         !partition().roles().has(PartitionRole::Extended) &&                    // not for extended, they have no file system
-        !partition().roles().has(PartitionRole::Unallocated);                   // and not for unallocated: no choice there
-
+        !partition().roles().has(PartitionRole::Unallocated) &&                 // and not for unallocated: no choice there
+                                                                                // do now show file system comboBox for open luks volumes.
+        !(partition().roles().has(PartitionRole::Luks) && partition().fileSystem().type() != FileSystem::Luks);
     dialogWidget().showFileSystem(showFileSystem);
 
     // when do we show the recreate file system check box?
@@ -235,7 +236,8 @@ void PartPropsDialog::updateHideAndShow()
         showFileSystem &&                                                       // only if we also show the file system
         partition().fileSystem().supportCreate() != FileSystem::cmdSupportNone &&  // and support creating this file system
         partition().fileSystem().type() != FileSystem::Unknown &&               // and not for unknown file systems
-        partition().state() != Partition::StateNew;                             // or new partitions
+        partition().state() != Partition::StateNew &&                           // or new partitions
+        !partition().roles().has(PartitionRole::Luks);                          // or encrypted filesystems
 
     dialogWidget().showCheckRecreate(showCheckRecreate);
 
@@ -253,21 +255,20 @@ void PartPropsDialog::updateHideAndShow()
 
 void PartPropsDialog::setupConnections()
 {
-    connect(&dialogWidget().label(), SIGNAL(textEdited(const QString&)), SLOT(setDirty()));
-    connect(&dialogWidget().fileSystem(), SIGNAL(currentIndexChanged(int)), SLOT(onFilesystemChanged(int)));
-    connect(&dialogWidget().checkRecreate(), SIGNAL(stateChanged(int)), SLOT(onRecreate(int)));
+    connect(&dialogWidget().label(), &QLineEdit::textEdited, this, &PartPropsDialog::setDirty2);
+    connect(&dialogWidget().fileSystem(), static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &PartPropsDialog::onFilesystemChanged);
+    connect(&dialogWidget().checkRecreate(), &QCheckBox::stateChanged, this, &PartPropsDialog::onRecreate);
 
     // We want to enable the OK-button whenever the user checks or unchecks a flag in the flag list.
     // But it seems Qt doesn't offer a foolproof way to detect if this has happened: The currentRow/ItemChanged
     // signal only means the _current_ item has changed, but not necessarily that it was checked/unchecked. And
     // itemClicked alone isn't enough either. We choose to rather enable the OK-button too often than too
     // seldom.
-    connect(&dialogWidget().listFlags(), SIGNAL(itemClicked(QListWidgetItem*)), SLOT(setDirty()));
-    connect(&dialogWidget().listFlags(), SIGNAL(currentRowChanged(int)), SLOT(setDirty()));
-
+    connect(&dialogWidget().listFlags(), &QListWidget::itemClicked, this, &PartPropsDialog::setDirty);
+    connect(&dialogWidget().listFlags(), &QListWidget::currentRowChanged, this, &PartPropsDialog::setDirty3);
 }
 
-void PartPropsDialog::setDirty()
+void PartPropsDialog::setDirty(void*)
 {
     okButton->setEnabled(true);
     okButton->setDefault(true);
@@ -279,34 +280,40 @@ void PartPropsDialog::setupFileSystemComboBox()
     QString selected;
     QStringList fsNames;
 
-    foreach(const FileSystem * fs, FileSystemFactory::map())
-    if (partition().fileSystem().type() == fs->type() || (fs->supportCreate() != FileSystem::cmdSupportNone && partition().capacity() >= fs->minCapacity() && partition().capacity() <= fs->maxCapacity())) {
-        QString name = fs->name();
-
-        if (partition().fileSystem().type() == fs->type())
-            selected = name;
-
-        // If the partition isn't extended, skip the extended FS
-        if (fs->type() == FileSystem::Extended && !partition().roles().has(PartitionRole::Extended))
+    for(const FileSystem * fs : FileSystemFactory::map())
+    {
+        // If the partition isn't encrypted, skip the luks FS
+        if (fs->type() == FileSystem::Luks && partition().fileSystem().type() != FileSystem::Luks)
             continue;
+        if (partition().fileSystem().type() == fs->type() || (fs->supportCreate() != FileSystem::cmdSupportNone &&
+                            partition().capacity() >= fs->minCapacity() && partition().capacity() <= fs->maxCapacity())) {
+            QString name = fs->name();
 
-        // The user cannot change the filesystem back to "unformatted" once a filesystem has been created.
-        if (fs->type() == FileSystem::Unformatted) {
-            // .. but if the file system is unknown to us, show the unformatted option as the currently selected one
-            if (partition().fileSystem().type() == FileSystem::Unknown) {
-                name = FileSystem::nameForType(FileSystem::Unformatted);
+            if (partition().fileSystem().type() == fs->type())
                 selected = name;
-            } else if (partition().fileSystem().type() != FileSystem::Unformatted && partition().state() != Partition::StateNew)
-                continue;
-        }
 
-        fsNames.append(name);
+            // If the partition isn't extended, skip the extended FS
+            if (fs->type() == FileSystem::Extended && !partition().roles().has(PartitionRole::Extended))
+                continue;
+
+            // The user cannot change the filesystem back to "unformatted" once a filesystem has been created.
+            if (fs->type() == FileSystem::Unformatted) {
+                // .. but if the file system is unknown to us, show the unformatted option as the currently selected one
+                if (partition().fileSystem().type() == FileSystem::Unknown) {
+                    name = FileSystem::nameForType(FileSystem::Unformatted);
+                    selected = name;
+                } else if (partition().fileSystem().type() != FileSystem::Unformatted && partition().state() != Partition::StateNew)
+                    continue;
+            }
+
+            fsNames.append(name);
+        }
     }
 
     qSort(fsNames.begin(), fsNames.end(), caseInsensitiveLessThan);
 
-    foreach(const QString & fsName, fsNames)
-    dialogWidget().fileSystem().addItem(createFileSystemColor(FileSystem::typeForName(fsName), 8), fsName);
+    for (const QString & fsName : fsNames)
+        dialogWidget().fileSystem().addItem(createFileSystemColor(FileSystem::typeForName(fsName), 8), fsName);
 
     dialogWidget().fileSystem().setCurrentIndex(dialogWidget().fileSystem().findText(selected));
 
@@ -340,7 +347,7 @@ void PartPropsDialog::onFilesystemChanged(int)
     } else {
         dialogWidget().fileSystem().disconnect(this);
         setupFileSystemComboBox();
-        connect(&dialogWidget().fileSystem(), SIGNAL(currentIndexChanged(int)), SLOT(onFilesystemChanged(int)));
+        connect(&dialogWidget().fileSystem(), static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &PartPropsDialog::onFilesystemChanged);
     }
 }
 
