@@ -1,6 +1,7 @@
 /*************************************************************************
  *  Copyright (C) 2008, 2010 by Volker Lanz <vl@fidra.de>                *
  *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
+ *  Copyright (C) 2016 by Teo Mrnjavac <teo@kde.org>                     *
  *                                                                       *
  *  This program is free software; you can redistribute it and/or        *
  *  modify it under the terms of the GNU General Public License as       *
@@ -70,9 +71,9 @@ SizeDialogBase::SizeDialogBase(QWidget* parent, Device& d, Partition& part, qint
     mainLayout->setSizeConstraint(QLayout::SetFixedSize);
     mainLayout->addWidget(dialogButtonBox);
 
-    connect(dialogButtonBox, SIGNAL(accepted()), this, SLOT(accept()));
-    connect(dialogButtonBox, SIGNAL(rejected()), this, SLOT(reject()));
-    connect(detailsButton, SIGNAL(clicked()), this, SLOT(toggleDetails()));
+    connect(dialogButtonBox, &QDialogButtonBox::accepted, this, &SizeDialogBase::accept);
+    connect(dialogButtonBox, &QDialogButtonBox::rejected, this, &SizeDialogBase::reject);
+    connect(detailsButton, &QPushButton::clicked, this, &SizeDialogBase::toggleDetails);
 }
 
 void SizeDialogBase::setupDialog()
@@ -100,6 +101,14 @@ void SizeDialogBase::setupDialog()
 
 void SizeDialogBase::setupConstraints()
 {
+    // Do not allow moving first sector if moving partition is disabled
+    bool moveAllowed = canMove();
+    if (!moveAllowed)
+        m_MinimumFirstSector = partition().firstSector();
+    dialogWidget().spinFreeBefore().setEnabled(moveAllowed);
+    dialogWidget().spinFreeAfter().setEnabled(moveAllowed);
+    detailsWidget().spinFirstSector().setEnabled(moveAllowed);
+
     setMinimumLength(!canShrink() ? partition().length() : qMax(partition().sectorsUsed(), partition().minimumSectors()));
     setMaximumLength(!canGrow() ? partition().length() : qMin(maximumLastSector() - minimumFirstSector() + 1, partition().maximumSectors()));
 
@@ -119,6 +128,7 @@ void SizeDialogBase::setupConstraints()
     const qint64 minCapacity = sectorsToDialogUnit(device(), minimumLength());
     const qint64 maxCapacity = sectorsToDialogUnit(device(), maximumLength());
     dialogWidget().spinCapacity().setRange(minCapacity, maxCapacity);
+    minCapacity > maxCapacity ? okButton->setEnabled(false) : okButton->setEnabled(true);
 
     const qint64 maxFree = totalCapacity - minCapacity;
 
@@ -133,16 +143,16 @@ void SizeDialogBase::setupConstraints()
 
 void SizeDialogBase::setupConnections()
 {
-    connect(&dialogWidget().partResizerWidget(), SIGNAL(firstSectorChanged(qint64)), SLOT(onResizerWidgetFirstSectorChanged(qint64)));
-    connect(&dialogWidget().partResizerWidget(), SIGNAL(lastSectorChanged(qint64)), SLOT(onResizerWidgetLastSectorChanged(qint64)));
+    connect(&dialogWidget().partResizerWidget(), &PartResizerWidget::firstSectorChanged, this, &SizeDialogBase::onResizerWidgetFirstSectorChanged);
+    connect(&dialogWidget().partResizerWidget(), &PartResizerWidget::lastSectorChanged, this, &SizeDialogBase::onResizerWidgetLastSectorChanged);
 
-    connect(&dialogWidget().spinFreeBefore(), SIGNAL(valueChanged(double)), SLOT(onSpinFreeBeforeChanged(double)));
-    connect(&dialogWidget().spinFreeAfter(), SIGNAL(valueChanged(double)), SLOT(onSpinFreeAfterChanged(double)));
-    connect(&dialogWidget().spinCapacity(), SIGNAL(valueChanged(double)), SLOT(onSpinCapacityChanged(double)));
+    connect(&dialogWidget().spinFreeBefore(), static_cast<void(QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged), this, &SizeDialogBase::onSpinFreeBeforeChanged);
+    connect(&dialogWidget().spinFreeAfter(), static_cast<void(QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged), this, &SizeDialogBase::onSpinFreeAfterChanged);
+    connect(&dialogWidget().spinCapacity(), static_cast<void(QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged), this, &SizeDialogBase::onSpinCapacityChanged);
 
-    connect(&detailsWidget().spinFirstSector(), SIGNAL(valueChanged(double)), SLOT(onSpinFirstSectorChanged(double)));
-    connect(&detailsWidget().spinLastSector(), SIGNAL(valueChanged(double)), SLOT(onSpinLastSectorChanged(double)));
-    connect(&detailsWidget().checkAlign(), SIGNAL(toggled(bool)), SLOT(onAlignToggled(bool)));
+    connect(&detailsWidget().spinFirstSector(), static_cast<void(QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged), this, &SizeDialogBase::onSpinFirstSectorChanged);
+    connect(&detailsWidget().spinLastSector(), static_cast<void(QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged), this, &SizeDialogBase::onSpinLastSectorChanged);
+    connect(&detailsWidget().checkAlign(), &QCheckBox::toggled, this, &SizeDialogBase::onAlignToggled);
 }
 
 void SizeDialogBase::toggleDetails()
