@@ -36,7 +36,7 @@ class TreeLog: public QWidget, public Ui::TreeLogBase
     Q_DISABLE_COPY(TreeLog)
 
 public:
-    TreeLog(QWidget* parent = NULL);
+    TreeLog(QWidget* parent = nullptr);
     ~TreeLog();
 
 Q_SIGNALS:
@@ -44,15 +44,15 @@ Q_SIGNALS:
 
 public:
     void init();
-
-protected Q_SLOTS:
     void onNewLogMessage(Log::Level logLevel, const QString& s);
-    void onHeaderContextMenu(const QPoint& pos);
+
     void onClearLog();
     void onSaveLog();
-    void on_m_TreeLog_customContextMenuRequested(const QPoint& pos);
 
 protected:
+    void on_m_TreeLog_customContextMenuRequested(const QPoint& pos);
+    void onHeaderContextMenu(const QPoint& pos);
+
     QTreeWidget& treeLog() {
         Q_ASSERT(m_TreeLog);
         return *m_TreeLog;
